cmd

package
v0.0.0-...-ca91ffb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 1, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Overview

SPDX-License-Identifier: MIT

Index

Constants

This section is empty.

Variables

var (
	Version string // Application version
	Date    string // Build date
	Commit  string // Git commit hash
	BuiltBy string // Builder identifier

)

Build information variables populated at build time

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately.

Types

type Asset

type Asset struct {
	Name     string // Original filename of the downloaded asset from GitHub
	Path     string // Local path where the asset was saved
	MIMEType string // MIME content type of the asset
}

Asset represents a successfully downloaded and verified release asset

Jump to